# Fibonacci

## Introduction

This is a small package that facilitates the generation of lists that contain Fibonacci sequences.

## Usage

Simply type the following to generate a list of 10 Fibonacci numbers starting with 0:

```shell
$ fibonacci
```

## Installation

This package will be available on pypi soon!